Module re_export

Module re_export 

re-export all the pub symbols from actix-web, no need to add additional actix-web dependency in Cargo.toml.

Modules

body
Traits and structures to aid consuming and writing HTTP payloads.
cookie
HTTP cookie parsing and cookie jar management.
dev
Lower-level types and re-exports.
error
Error and Result module
guard
Route guards.
http
Various HTTP related types.
middleware
A collection of common middleware.
mime
Mime
rt
A selection of re-exports from tokio and actix-rt.
test
Various helpers for Actix applications to use during testing.
web
Essentials helper functions and types for application registration.

Macros

services
Macro to help register different types of services at the same time.

Structs

App
The top-level builder for an Actix Web application.
CookieIdentityPolicy
Use cookies for request identity storage.
Cors
Builder for CORS middleware.
CustomizeResponder
Allows overriding status code and headers (including cookies) for a Responder.
Directory
A directory; responds with the generated directory listing.
Error
General purpose Actix Web error.
Files
Static files handling service.
FilesService
Assembled file serving service.
HttpRange
HTTP Range header representation.
HttpRequest
An incoming request.
HttpResponse
An outgoing response.
HttpResponseBuilder
An HTTP response builder.
HttpServer
An HTTP Server.
Identity
The extractor type to obtain your identity from a request.
IdentityService
Request identity middleware
NamedFile
A file with an associated name.
Resource
A collection of Routes that respond to the same path pattern.
Route
A request handler with guards.
Scope
A collection of Routes, Resources, or other services that share a common path prefix.

Enums

CorsError
Errors that can occur when processing CORS guarded requests.
Either
Combines two extractor or responder types into a single type.

Traits

FromRequest
A type that implements FromRequest is called an extractor and can extract data from the request. Some types that implement this trait are: Json, Header, and Path.
Handler
The interface for request handlers.
HttpMessage
Trait that implements general purpose operations on HTTP messages.
IdentityPolicy
Identity policy definition.
RequestIdentity
Helper trait that allows to get Identity.
Responder
Trait implemented by types that can be converted to an HTTP response.
ResponseError
Errors that can generate responses.

Functions

file_extension_to_mime
Return the MIME type associated with a filename extension (case-insensitive). If ext is empty or no associated type for the extension was found, returns the type application/octet-stream.

Type Aliases

Result
A convenience Result for Actix Web operations.

Attribute Macros

connect
delete
get
head
main
options
patch
post
put
route
Creates resource handler, allowing multiple HTTP method guards.
routes
Creates resource handler, allowing multiple HTTP methods and paths.
scope
Prepends a path prefix to all handlers using routing macros inside the attached module.
test
Marks async test functions to use the Actix Web system entry-point.
trace