HttpServiceFactory
spa_
server
0.1.0
Http
Service
Factory
Required Methods
register
Implementations on Foreign Types
(A, B)
(A, B, C)
(A, B, C, D)
(A, B, C, D, E)
(A, B, C, D, E, F)
(A, B, C, D, E, F, G)
(A, B, C, D, E, F, G, H)
(A, B, C, D, E, F, G, H, I)
(A, B, C, D, E, F, G, H, I, J)
(A, B, C, D, E, F, G, H, I, J, K)
(A, B, C, D, E, F, G, H, I, J, K, L)
(A,)
Vec<T>
Implementors
In spa_
server::
re_
export::
dev
spa_server
::
re_export
::
dev
Trait
Http
Service
Factory
pub trait HttpServiceFactory { // Required method fn
register
(self, config: &mut
AppService
); }
Required Methods

fn
register
(self, config: &mut
AppService
)
Implementations on Foreign Types


impl<A>
HttpServiceFactory
for
(A,)
where A:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B>
HttpServiceFactory
for
(A, B)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C>
HttpServiceFactory
for
(A, B, C)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C, D>
HttpServiceFactory
for
(A, B, C, D)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
, D:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C, D, E>
HttpServiceFactory
for
(A, B, C, D, E)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
, D:
HttpServiceFactory
, E:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C, D, E, F>
HttpServiceFactory
for
(A, B, C, D, E, F)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
, D:
HttpServiceFactory
, E:
HttpServiceFactory
, F:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C, D, E, F, G>
HttpServiceFactory
for
(A, B, C, D, E, F, G)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
, D:
HttpServiceFactory
, E:
HttpServiceFactory
, F:
HttpServiceFactory
, G:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C, D, E, F, G, H>
HttpServiceFactory
for
(A, B, C, D, E, F, G, H)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
, D:
HttpServiceFactory
, E:
HttpServiceFactory
, F:
HttpServiceFactory
, G:
HttpServiceFactory
, H:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C, D, E, F, G, H, I>
HttpServiceFactory
for
(A, B, C, D, E, F, G, H, I)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
, D:
HttpServiceFactory
, E:
HttpServiceFactory
, F:
HttpServiceFactory
, G:
HttpServiceFactory
, H:
HttpServiceFactory
, I:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C, D, E, F, G, H, I, J>
HttpServiceFactory
for
(A, B, C, D, E, F, G, H, I, J)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
, D:
HttpServiceFactory
, E:
HttpServiceFactory
, F:
HttpServiceFactory
, G:
HttpServiceFactory
, H:
HttpServiceFactory
, I:
HttpServiceFactory
, J:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C, D, E, F, G, H, I, J, K>
HttpServiceFactory
for
(A, B, C, D, E, F, G, H, I, J, K)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
, D:
HttpServiceFactory
, E:
HttpServiceFactory
, F:
HttpServiceFactory
, G:
HttpServiceFactory
, H:
HttpServiceFactory
, I:
HttpServiceFactory
, J:
HttpServiceFactory
, K:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<A, B, C, D, E, F, G, H, I, J, K, L>
HttpServiceFactory
for
(A, B, C, D, E, F, G, H, I, J, K, L)
where A:
HttpServiceFactory
, B:
HttpServiceFactory
, C:
HttpServiceFactory
, D:
HttpServiceFactory
, E:
HttpServiceFactory
, F:
HttpServiceFactory
, G:
HttpServiceFactory
, H:
HttpServiceFactory
, I:
HttpServiceFactory
, J:
HttpServiceFactory
, K:
HttpServiceFactory
, L:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)

impl<T>
HttpServiceFactory
for
Vec
<T>
where T:
HttpServiceFactory
,

fn
register
(self, config: &mut
AppService
)
Implementors


impl
HttpServiceFactory
for
Files

impl
HttpServiceFactory
for
NamedFile

impl
HttpServiceFactory
for
Redirect

impl<T, B>
HttpServiceFactory
for
Resource
<T>
where T:
ServiceFactory
<
ServiceRequest
, Config =
()
, Response =
ServiceResponse
<B>, Error =
Error
, InitError =
()
> + 'static, B:
MessageBody
+ 'static,

impl<T, B>
HttpServiceFactory
for
Scope
<T>
where T:
ServiceFactory
<
ServiceRequest
, Config =
()
, Response =
ServiceResponse
<B>, Error =
Error
, InitError =
()
> + 'static, B:
MessageBody
+ 'static,