CookieIdentityPolicy

Struct CookieIdentityPolicy 

pub struct CookieIdentityPolicy(/* private fields */);
Use cookies for request identity storage.

The constructors take a key as an argument. This is the private key for cookie - when this value is changed, all identities are lost. The constructors will panic if the key is less than 32 bytes in length.

Example

use actix_web::App;
use actix_identity::{CookieIdentityPolicy, IdentityService};

let app = App::new().wrap(IdentityService::new(
    // <- create identity middleware
    CookieIdentityPolicy::new(&[0; 32])  // <- construct cookie policy
           .domain("www.rust-lang.org")
           .name("actix_auth")
           .path("/")
           .secure(true),
));

Implementations

Source

impl CookieIdentityPolicy

pub fn new(key: &[u8]) -> CookieIdentityPolicy

Construct new CookieIdentityPolicy instance.

Panics if key length is less than 32 bytes.

pub fn path<S>(self, value: S) -> CookieIdentityPolicy
where S: Into<String>,

Sets the path field in the session cookie being built.

pub fn name<S>(self, value: S) -> CookieIdentityPolicy
where S: Into<String>,

Sets the name field in the session cookie being built.

pub fn domain<S>(self, value: S) -> CookieIdentityPolicy
where S: Into<String>,

Sets the domain field in the session cookie being built.

pub fn secure(self, value: bool) -> CookieIdentityPolicy

Sets the secure field in the session cookie being built.

If the secure field is set, a cookie will only be transmitted when the connection is secure - i.e. https

pub fn max_age(self, seconds: i64) -> CookieIdentityPolicy

Sets the max-age field in the session cookie being built with given number of seconds.

pub fn max_age_time(self, value: Duration) -> CookieIdentityPolicy

Sets the max-age field in the session cookie being built with time::Duration.

pub fn http_only(self, http_only: bool) -> CookieIdentityPolicy

Sets the http_only field in the session cookie being built.

pub fn same_site(self, same_site: SameSite) -> CookieIdentityPolicy

Sets the same_site field in the session cookie being built.

pub fn visit_deadline(self, value: Duration) -> CookieIdentityPolicy

Accepts only users whose cookie has been seen before the given deadline

By default visit deadline is disabled.

pub fn login_deadline(self, value: Duration) -> CookieIdentityPolicy

Accepts only users which has been authenticated before the given deadline

By default login deadline is disabled.