Identity

Struct Identity 

pub struct Identity(/* private fields */);
The extractor type to obtain your identity from a request.

use actix_web::*;
use actix_identity::Identity;

fn index(id: Identity) -> Result<String> {
    // access request identity
    if let Some(id) = id.identity() {
        Ok(format!("Welcome! {}", id))
    } else {
        Ok("Welcome Anonymous!".to_owned())
    }
}

fn login(id: Identity) -> HttpResponse {
    id.remember("User1".to_owned()); // <- remember identity
    HttpResponse::Ok().finish()
}

fn logout(id: Identity) -> HttpResponse {
    id.forget(); // <- remove identity
    HttpResponse::Ok().finish()
}

Implementations

Source

impl Identity

pub fn identity(&self) -> Option<String>

Return the claimed identity of the user associated request or None if no identity can be found associated with the request.

pub fn remember(&self, identity: String)

Remember identity.

pub fn forget(&self)

This method is used to ‘forget’ the current identity on subsequent requests.