re-export all the pub symbols from actix-web, no need to add additional actix-web dependency in Cargo.toml.
Modules
- body
- Traits and structures to aid consuming and writing HTTP payloads.
- cookie
- HTTP cookie parsing and cookie jar management.
- dev
- Lower-level types and re-exports.
- error
- Error and Result module
- guard
- Route guards.
- http
- Various HTTP related types.
- middleware
- A collection of common middleware.
- mime
- Mime
- rt
- A selection of re-exports from
tokioandactix-rt. - test
- Various helpers for Actix applications to use during testing.
- web
- Essentials helper functions and types for application registration.
Macros
- services
- Macro to help register different types of services at the same time.
Structs
- App
- The top-level builder for an Actix Web application.
- Cookie
Identity Policy - Use cookies for request identity storage.
- Cors
- Builder for CORS middleware.
- Customize
Responder - Allows overriding status code and headers (including cookies) for a
Responder. - Directory
- A directory; responds with the generated directory listing.
- Error
- General purpose Actix Web error.
- Files
- Static files handling service.
- Files
Service - Assembled file serving service.
- Http
Range - HTTP Range header representation.
- Http
Request - An incoming request.
- Http
Response - An outgoing response.
- Http
Response Builder - An HTTP response builder.
- Http
Server - An HTTP Server.
- Identity
- The extractor type to obtain your identity from a request.
- Identity
Service - Request identity middleware
- Named
File - A file with an associated name.
- Resource
- A collection of
Routes that respond to the same path pattern. - Route
- A request handler with guards.
- Scope
- A collection of
Routes,Resources, or other services that share a common path prefix.
Enums
- Cors
Error - Errors that can occur when processing CORS guarded requests.
- Either
- Combines two extractor or responder types into a single type.
Traits
- From
Request - A type that implements
FromRequestis called an extractor and can extract data from the request. Some types that implement this trait are:Json,Header, andPath. - Handler
- The interface for request handlers.
- Http
Message - Trait that implements general purpose operations on HTTP messages.
- Identity
Policy - Identity policy definition.
- Request
Identity - Helper trait that allows to get Identity.
- Responder
- Trait implemented by types that can be converted to an HTTP response.
- Response
Error - Errors that can generate responses.
Functions
- file_
extension_ to_ mime - Return the MIME type associated with a filename extension (case-insensitive).
If
extis empty or no associated type for the extension was found, returns the typeapplication/octet-stream.
Type Aliases
Attribute Macros
- connect
- delete
- get
- head
- main
- options
- patch
- post
- put
- route
- Creates resource handler, allowing multiple HTTP method guards.
- routes
- Creates resource handler, allowing multiple HTTP methods and paths.
- scope
- Prepends a path prefix to all handlers using routing macros inside the attached module.
- test
- Marks async test functions to use the Actix Web system entry-point.
- trace