pub struct CookieIdentityPolicy(/* private fields */);Expand description
Use cookies for request identity storage.
The constructors take a key as an argument. This is the private key for cookie - when this value is changed, all identities are lost. The constructors will panic if the key is less than 32 bytes in length.
Example
use actix_web::App;
use actix_identity::{CookieIdentityPolicy, IdentityService};
let app = App::new().wrap(IdentityService::new(
// <- create identity middleware
CookieIdentityPolicy::new(&[0; 32]) // <- construct cookie policy
.domain("www.rust-lang.org")
.name("actix_auth")
.path("/")
.secure(true),
));Implementations
Sourceimpl CookieIdentityPolicy
impl CookieIdentityPolicy
Sourcepub fn new(key: &[u8]) -> CookieIdentityPolicy
pub fn new(key: &[u8]) -> CookieIdentityPolicy
Construct new CookieIdentityPolicy instance.
Panics if key length is less than 32 bytes.
Sourcepub fn path<S>(self, value: S) -> CookieIdentityPolicy
pub fn path<S>(self, value: S) -> CookieIdentityPolicy
Sets the path field in the session cookie being built.
Sourcepub fn name<S>(self, value: S) -> CookieIdentityPolicy
pub fn name<S>(self, value: S) -> CookieIdentityPolicy
Sets the name field in the session cookie being built.
Sourcepub fn domain<S>(self, value: S) -> CookieIdentityPolicy
pub fn domain<S>(self, value: S) -> CookieIdentityPolicy
Sets the domain field in the session cookie being built.
Sourcepub fn secure(self, value: bool) -> CookieIdentityPolicy
pub fn secure(self, value: bool) -> CookieIdentityPolicy
Sets the secure field in the session cookie being built.
If the secure field is set, a cookie will only be transmitted when the
connection is secure - i.e. https
Sourcepub fn max_age(self, seconds: i64) -> CookieIdentityPolicy
pub fn max_age(self, seconds: i64) -> CookieIdentityPolicy
Sets the max-age field in the session cookie being built with given number of seconds.
Sourcepub fn max_age_time(self, value: Duration) -> CookieIdentityPolicy
pub fn max_age_time(self, value: Duration) -> CookieIdentityPolicy
Sets the max-age field in the session cookie being built with time::Duration.
Sourcepub fn http_only(self, http_only: bool) -> CookieIdentityPolicy
pub fn http_only(self, http_only: bool) -> CookieIdentityPolicy
Sets the http_only field in the session cookie being built.
Sourcepub fn same_site(self, same_site: SameSite) -> CookieIdentityPolicy
pub fn same_site(self, same_site: SameSite) -> CookieIdentityPolicy
Sets the same_site field in the session cookie being built.
Sourcepub fn visit_deadline(self, value: Duration) -> CookieIdentityPolicy
pub fn visit_deadline(self, value: Duration) -> CookieIdentityPolicy
Accepts only users whose cookie has been seen before the given deadline
By default visit deadline is disabled.
Sourcepub fn login_deadline(self, value: Duration) -> CookieIdentityPolicy
pub fn login_deadline(self, value: Duration) -> CookieIdentityPolicy
Accepts only users which has been authenticated before the given deadline
By default login deadline is disabled.