pub trait RequestIdentity {
// Required method
fn get_identity(&self) -> Option<String>;
}Expand description
Helper trait that allows to get Identity.
It could be used in middleware but identity policy must be set before any other middleware that needs identity
RequestIdentity is implemented both for ServiceRequest and HttpRequest.